@@ -2,6 +2,7 @@
 """Initialize the cert_manager module."""
 
 from .acme import ACMEAccount
+from .admin import Admin
 from .client import Client
 from ._helpers import Pending
 from .organization import Organization
@@ -9,4 +10,4 @@ from .person import Person
 from .smime import SMIME
 from .ssl import SSL
 
-__all__ = ["ACMEAccount", "Client", "Organization", "Pending", "Person", "SMIME", "SSL"]
+__all__ = ["ACMEAccount", "Admin", "Client", "Organization", "Pending", "Person", "SMIME", "SSL"]
